@@ -2,7 +2,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; File:         efs-dired.el
-;; Release:      $efs release: 1.18 $
+;; Release:      $efs release: 1.23 $
 ;; Version:      #Revision: 1.32 $
 ;; RCS:          
 ;; Description:  Extends much of Dired to work under efs.
@@ -22,7 +22,7 @@
 (autoload 'dired-shell-call-process "dired-shell")
 
 (defconst efs-dired-version
-  (concat (substring "$efs release: 1.18 $" 14 -2)
+  (concat (substring "$efs release: 1.23 $" 14 -2)
 	  "/"
 	  (substring "#Revision: 1.32 $" 11 -2)))
 
@@ -951,7 +951,7 @@ ESC or `q' to not overwrite any of the remaining files,
   (let* ((compressed-fn (efs-dired-make-compressed-filename file))
 	 (host (car (efs-ftp-path file)))
 	 (host-type (efs-host-type host)))
-    (cond ((file-symlink-p file)
+    (cond ((efs-file-symlink-p file)
 	   (if cont
 	       (efs-call-cont
 		cont 'failed
